@@ -24,15 +24,6 @@ if find_package("psi4"):
 if find_package("ase"):
     from cclib.bridge.cclib2ase import makease
 
-if find_package("horton"):
-    try:
-        from horton import __version__
-    except Exception:
-        pass
-    else:
-        if (__version__[0] == '2'):
-            from cclib.bridge.cclib2horton import makehorton
-
 if find_package("iodata"):
     from cclib.bridge.cclib2horton import makehorton
 
