@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2020, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -51,14 +51,16 @@ class GAMESSUK(logfileparser.Logfile):
         if "version" in line:
             search = re.search(r"\sversion\s*(\d\.\d)", line)
             if search:
-                self.metadata["package_version"] = search.groups()[0]
+                package_version = search.groups()[0]
+                self.metadata["package_version"] = package_version
+                self.metadata["legacy_package_version"] = package_version
         if "Revision" in line:
             revision = line.split()[1]
-            # Don't add revision information to the main package version for now.
-            # if "package_version" in self.metadata:
-            #     package_version = "{}.r{}".format(self.metadata["package_version"],
-            #                                       revision)
-            #     self.metadata["package_version"] = package_version
+            package_version = self.metadata.get("package_version")
+            if package_version:
+                self.metadata["package_version"] = "{}+{}".format(
+                    package_version, revision
+                )
 
         if line[1:22] == "total number of atoms":
             natom = int(line.split()[-1])
@@ -361,11 +363,11 @@ class GAMESSUK(logfileparser.Logfile):
             if not hasattr(self, "mpenergies"):
                 self.mpenergies = []
             self.mpenergies.append([])
-            self.mp2correction = self.float(line.split()[-1])
+            self.mp2correction = utils.float(line.split()[-1])
             self.mp2energy = self.scfenergies[-1] + self.mp2correction
             self.mpenergies[-1].append(utils.convertor(self.mp2energy, "hartree", "eV"))
         if line[10:41] == "third order perturbation energy":
-            self.mp3correction = self.float(line.split()[-1])
+            self.mp3correction = utils.float(line.split()[-1])
             self.mp3energy = self.mp2energy + self.mp3correction
             self.mpenergies[-1].append(utils.convertor(self.mp3energy, "hartree", "eV"))
 
@@ -377,7 +379,7 @@ class GAMESSUK(logfileparser.Logfile):
             equals = next(inputfile)
             blank = next(inputfile)
             atomname = next(inputfile)
-            basisregexp = re.compile("\d*(\D+)")  # Get everything after any digits
+            basisregexp = re.compile(r"\d*(\D+)")  # Get everything after any digits
             shellcounter = 1
             while line != equals:
                 gbasis = []  # Stores basis sets on one atom
