@@ -8,8 +8,6 @@
 """Parser for Gaussian output files"""
 
 
-from __future__ import print_function
-
 import re
 
 import numpy
@@ -762,7 +760,7 @@ class Gaussian(logfileparser.Logfile):
                         matches.get('RMSDP', numpy.nan),
                         matches.get('MaxDP', numpy.nan)
                     ]
-                    if len(self.scftargets[0]) == 3:
+                    if hasattr(self, "scftargets") and len(self.scftargets[0]) == 3:
                         scfvalues_step.append(matches.get('DE', numpy.nan))
                     scfvalues.append(scfvalues_step)
 
