@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2017, the cclib development team
+# Copyright (c) 2020, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
@@ -63,11 +63,10 @@ class Jaguar(logfileparser.Logfile):
         # Extract the package version number.
         if "Jaguar version" in line:
             tokens = line.split()
-            # Don't add revision information to the main package
-            # version for now.
-            # package_version = "{}.r{}".format(tokens[3][:-1], tokens[5])
-            package_version = tokens[3][:-1]
+            base_version = tokens[3][:-1]
+            package_version = "{}+{}".format(base_version, tokens[5])
             self.metadata["package_version"] = package_version
+            self.metadata["legacy_package_version"] = base_version
 
         # Extract the basis set name
         if line[2:12] == "basis set:":
@@ -204,7 +203,7 @@ class Jaguar(logfileparser.Logfile):
             if not hasattr(self, "atomcoords") or line[1:21] == "Symmetrized geometry":
                 # Wipe the "Input geometry" if "Symmetrized geometry" present
                 self.atomcoords = []
-            p = re.compile("(\D+)\d+")  # One/more letters followed by a number
+            p = re.compile(r"(\D+)\d+")  # One/more letters followed by a number
             atomcoords = []
             atomnos = []
             angstrom = next(inputfile)
@@ -614,6 +613,7 @@ class Jaguar(logfileparser.Logfile):
 
             self.vibfreqs = []
             self.vibdisps = []
+            self.vibrmasses = []
             forceconstants = False
             intensities = False
             while line.strip():
@@ -647,8 +647,12 @@ class Jaguar(logfileparser.Logfile):
                         self.vibirs = []
                     self.vibirs.extend(list(map(float, line[1:])))
                     line = next(inputfile).split()
+                self.vibrmasses.extend(list(map(float, line[2:])))
                 if forceconstants:
-                    line = next(inputfile)
+                    line = next(inputfile).split()
+                    if not hasattr(self, "vibfconsts"):
+                        self.vibfconsts = []
+                    self.vibfconsts.extend(list(map(float, line[2:])))
 
                 # Start parsing the displacements.
                 # Variable 'q' holds up to 7 lists of triplets.
@@ -672,8 +676,11 @@ class Jaguar(logfileparser.Logfile):
             # Convert new data to arrays.
             self.vibfreqs = numpy.array(self.vibfreqs, "d")
             self.vibdisps = numpy.array(self.vibdisps, "d")
+            self.vibrmasses = numpy.array(self.vibrmasses, "d")
             if hasattr(self, "vibirs"):
                 self.vibirs = numpy.array(self.vibirs, "d")
+            if hasattr(self, "vibfconsts"):
+                self.vibfconsts = numpy.array(self.vibfconsts, "d")
 
         # Parse excited state output (for CIS calculations).
         # Jaguar calculates only singlet states.
@@ -686,7 +693,7 @@ class Jaguar(logfileparser.Logfile):
                 self.etsecs = []
                 self.etsyms = []
             etenergy = float(line.split()[3])
-            etenergy = utils.convertor(etenergy, "eV", "cm-1")
+            etenergy = utils.convertor(etenergy, "eV", "wavenumber")
             self.etenergies.append(etenergy)
 
             self.skip_lines(inputfile, ['line', 'line', 'line', 'line'])
