@@ -1,36 +1,18 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2018, the cclib development team
+# Copyright (c) 2020, the cclib development team
 #
 # This file is part of cclib (http://cclib.github.io) and is distributed under
 # the terms of the BSD 3-Clause License.
 
 """Utilities often used by cclib parsers and scripts"""
 
+import importlib
 import sys
+from itertools import accumulate
+
 import numpy
 import periodictable
-import scipy.spatial.transform
-
-
-# See https://github.com/kachayev/fn.py/commit/391824c43fb388e0eca94e568ff62cc35b543ecb
-if sys.version_info <= (3, 3):
-    import operator
-    def accumulate(iterable, func=operator.add):
-        """Return running totals"""
-        # accumulate([1,2,3,4,5]) --> 1 3 6 10 15
-        # accumulate([1,2,3,4,5], operator.mul) --> 1 2 6 24 120
-        it = iter(iterable)
-        try:
-            total = next(it)
-        except StopIteration:
-            return
-        yield total
-        for element in it:
-            total = func(total, element)
-            yield total
-else:
-    from itertools import accumulate
 
 
 def find_package(package):
@@ -38,13 +20,13 @@ def find_package(package):
 
     Derived from https://stackoverflow.com/a/14050282
     """
-    if sys.version_info.major == 2:
-        import pkgutil
-        return pkgutil.find_loader(package) is not None
-    else:
-        import importlib
-        module_spec = importlib.util.find_spec(package)
-        return module_spec is not None and module_spec.loader is not None
+    module_spec = importlib.util.find_spec(package)
+    return module_spec is not None and module_spec.loader is not None
+
+
+_found_scipy = find_package("scipy")
+if _found_scipy:
+    import scipy.spatial
 
 
 def symmetrize(m, use_triangle='lower'):
@@ -185,8 +167,11 @@ def get_rotation(a, b):
         a (np.ndarray): positions with shape(N,3)
         b (np.ndarray): positions with shape(N,3)
     Returns:
-        scipy.spatial.transform.Rotation
+        A scipy.spatial.transform.Rotation object
     """
+    if not _found_scipy:
+        raise ImportError("You must install `scipy` to use this function")
+
     assert a.shape == b.shape
     if a.shape[0] == 1:
         return scipy.spatial.transform.Rotation.from_euler('xyz', [0,0,0])
@@ -213,7 +198,7 @@ def get_rotation(a, b):
             r = scipy.spatial.transform.Rotation.from_dcm(rmat)
     return r
 
-class PeriodicTable(object):
+class PeriodicTable:
     """Allows conversion between element name and atomic no."""
 
     def __init__(self):
