@@ -7,8 +7,6 @@
 
 """Run data tests for cclib."""
 
-from __future__ import print_function
-
 import importlib
 import logging
 import os
@@ -27,8 +25,9 @@ sys.path.insert(1, os.path.join(__filedir__, 'data'))
 
 
 parser_names = [
-    "ADF", "DALTON", "GAMESS", "GAMESSUK", "Gaussian", "Jaguar", "Molpro",
-    "Molcas", "MOPAC", "NWChem", "ORCA", "Psi4", "QChem", "Turbomole",
+    "ADF", "DALTON", "FChk", "GAMESS", "GAMESSUK", "Gaussian", "Jaguar",
+     "Molpro", "Molcas", "MOPAC", "NWChem", "ORCA", "Psi4", "QChem",
+    "Turbomole",
 ]
 all_parsers = {name: getattr(cclib.parser, name) for name in parser_names}
 
@@ -124,7 +123,7 @@ def ccdata_getattribute_with_coverage(self, attr):
     return object.__getattribute__(self, attr)
 
 
-class DataSuite(object):
+class DataSuite:
     """Suite containing data (logfile) tests in cclib.
 
     This is supposed to represent a single run of the entire data test suite in cclib or
